@@ -309,11 +309,11 @@ class StarFox64Context(CommonContext):
   slot_data = {}
   n64_sockets = set()
 
-  def __init__(self, server_address, slot_name, password, ready_callback=None, error_callback=None):
+  def __init__(self, server_address, password, ready_callback=None, error_callback=None):
     super().__init__(server_address, password)
     self.ready_callback = ready_callback
     self.error_callback = error_callback
-    self.username = slot_name
+    self.username = urllib.parse.urlparse(server_address).username
     if self.ready_callback:
       from kivy.clock import Clock
       Clock.schedule_once(self.ready_callback, 0.1)
@@ -627,14 +627,14 @@ def close_program():
     program.kill()
     program = None
 
-def launch(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def launch(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """
     Launch the client
     """
     logging.getLogger("StarFox64Client")
 
     async def main():
-        ctx = StarFox64Context(server_address, slot_name, password, ready_callback, error_callback)
+        ctx = StarFox64Context(server_address, password, ready_callback, error_callback)
         if ctx._can_takeover_existing_gui():
             await ctx._takeover_existing_gui() 
         else:
@@ -670,6 +670,6 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
             error_callback()
 
 
-def main(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def main(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, slot_name, password, ready_callback, error_callback)
+    launch(server_address, password, ready_callback, error_callback)
